"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const architect_1 = require("@angular-devkit/architect");
const SVGSpriter = require("svg-sprite");
const fs_1 = require("fs");
const path_1 = require("path");
const glob_1 = require("glob");
exports.default = architect_1.createBuilder(copyFileBuilder);
function copyFileBuilder(options, context) {
    return __awaiter(this, void 0, void 0, function* () {
        context.reportStatus(`Compiling ${options.source} into ${options.destination}.`);
        try {
            const resultFilePath = yield compile(options);
            context.reportStatus('Done.');
            context.logger.info('Compiled: ' + resultFilePath);
            return { success: true };
        }
        catch (e) {
            context.reportStatus('Error.');
            context.logger.error('Compilation failed.');
            return {
                success: false,
                error: e.message
            };
        }
    });
}
function compile(options) {
    const spriter = new SVGSpriter(Object.assign(Object.assign({ mode: {
            symbol: true
        } }, options.shape ? { shape: options.shape } : {}), options.svg ? { shape: options.svg } : {}));
    return new Promise((resolve, reject) => {
        glob_1.glob(options.source, (err, files) => {
            if (err) {
                reject(err);
                return;
            }
            if (!files.length) {
                reject(new Error('No source files found'));
                return;
            }
            files.forEach(file => {
                spriter.add(file, path_1.basename(file), fs_1.readFileSync(file, { encoding: 'utf-8' }));
            });
            spriter.compile(function (error, result) {
                if (error) {
                    reject(new Error(error.message));
                    return;
                }
                const file = result.symbol.sprite;
                if (file) {
                    fs_1.mkdirSync(path_1.dirname(options.destination), { recursive: true });
                    fs_1.writeFileSync(options.destination, file.contents);
                    resolve(options.destination);
                    return;
                }
                reject(new Error('Got no result file'));
            });
        });
    });
}
//# sourceMappingURL=index.js.map